@@ -4,6 +4,18 @@ class VKAPI:
     def __init__(self, token, group_id):
         self.token = token
         self.group_id = group_id
+        self.api_link = 'https://api.vk.com/method/{method}'
+
+    def call(self, method, **kwargs):
+        """Call method from VK API"""
+        params = {}
+        params.update(**kwargs)
+        params['v'] = '5.103'
+        api_url = self.api_link.format(method=method)
+        response = requests.get(api_url, params=params).json()
+
+        return response
+
 
     def updateLongpoll(self):
         api_url = 'https://api.vk.com/method/groups.getLongPollServer?access_token={0}&group_id={1}&v=5.103'.format(self.token, self.group_id)
@@ -43,8 +55,7 @@ class VKAPI:
         path - path of image file
 
         """
-        server_url = 'https://api.vk.com/method/photos.getMessagesUploadServer?peer_id={0}&access_token={1}&v=5.103'.format(peer_id, self.token)
-        upload_server = requests.get(server_url).json()
+        upload_server = self.call('photos.getMessagesUploadServer', peer_id=peer_id, access_token=self.token)
 
         image = self.openFile(path)
 
@@ -52,12 +63,25 @@ class VKAPI:
         post_response = requests.post(post_url, files=dict(file=image)).json()
         server, photo, vk_hash = post_response['server'], post_response['photo'], post_response['hash']
 
-        save_url = 'http://api.vk.com/method/photos.saveMessagesPhoto?photo={0}&server={1}&hash={2}&access_token={3}&v=5.103'.format(photo, server, vk_hash, self.token)
-        save_response  = requests.get(save_url).json()
+        save_response = self.call('photos.saveMessagesPhoto', photo=photo, server=server, hash=vk_hash, access_token=self.token)
         upload_image = 'photo{0}_{1}'.format(save_response['response'][0]['owner_id'], save_response['response'][0]['id'])
 
         return upload_image
 
+
+    def sendImage(self, peer_id, path, random_id):
+        """Send Image ONLY for message
+        
+        peer_id - user id to whom the image is sent
+        path - path of image file
+        random_id - random integer number, but use a random.randint(1, 10 ** 8)
+
+        """
+        photo = self.uploadImage(peer_id, path)
+        response_send = self.call('messages.send', attachment=photo, peer_id=peer_id, access_token=self.token, random_id=random_id)
+
+        return response_send
+
     def uploadDocument(self, peer_id, path):
         """Upload and save documents ONLY for message 
         
@@ -65,9 +89,7 @@ class VKAPI:
         path - path of image file
         
         """
-        
-        server_url = 'https://api.vk.com/method/docs.getMessagesUploadServer?type=doc&peer_id={0}&access_token={1}&v=5.103'.format(peer_id, self.token)
-        upload_server = requests.get(server_url).json()
+        upload_server = self.call('docs.getMessagesUploadServer', type='doc', peer_id=peer_id, access_token=self.token)
 
         document = self.openFile(path)
 
@@ -75,11 +97,9 @@ class VKAPI:
         post_response = requests.post(post_url, files=dict(file=document)).json()
         document = post_response['file']
 
-        save_url = 'https://api.vk.com/method/docs.save?file={0}&access_token={1}&v=5.103'.format(document, self.token)
-        save_response = requests.get(save_url).json()
+        save_response = self.call('docs.save', file=document, access_token=self.token)
         upload_document = 'doc{0}_{1}'.format(save_response['response']['doc']['owner_id'], save_response['response']['doc']['id'])
         
-        return upload_document
     
     def sendDocument(self, peer_id, path, random_id):
         """Send Document ONLY for message
@@ -91,22 +111,9 @@ class VKAPI:
         """
 
         document = self.uploadDocument(peer_id, path)
-        url_send = 'https://api.vk.com/method/messages.send?attachment={0}&peer_id={1}&access_token={2}&random_id={3}&v=5.103'.format(document, peer_id, self.token, random_id)
-        response_send = requests.get(url_send).json()
-
-    
-    def sendImage(self, peer_id, path, random_id):
-        """Send Image ONLY for message
-        
-        peer_id - user id to whom the image is sent
-        path - path of image file
-        random_id - random integer number, but use a random.randint(1, 10 ** 8)
-
-        """
-        photo = self.uploadImage(peer_id, path)
-        url_send = 'https://api.vk.com/method/messages.send?attachment={0}&peer_id={1}&access_token={2}&random_id={3}&v=5.103'.format(photo, peer_id, self.token, random_id)
-        response_send = requests.get(url_send).json()
+        response_send = self.call('messages.send', attachment=document, peer_id=peer_id, access_token=self.token, random_id=random_id)
 
+        return response_send
     
     def sendMessage(self, message, peer_id, random_id):
         """Send message
@@ -115,8 +122,51 @@ class VKAPI:
         random_id - random integer number, but use a random.randint(1, 10 ** 8)
         
         """
-        url_send = 'https://api.vk.com/method/messages.send?message={0}&peer_id={1}&access_token={2}&random_id={3}&v=5.103'.format(message, peer_id, self.token, random_id)
-        response_send = requests.get(url_send).json()
+        response = self.call('messages.send', peer_id=peer_id, message=message, random_id=random_id, access_token=self.token)
+
+        return reponse 
+
+    def enableOnline(self):
+        enable_online = self.call('groups.enableOnline', group_id=self.group_id, access_token=self.token)
+
+        return enable_online
+
+    def disableOnline(self):
+        disable_online = self.call('groups.disableOnline', group_id=self.group_id, access_token=self.token)
+
+        return disable_online
+
+    def getBannedList(self):
+        banned_list = self.call('groups.getBanned', group_id=self.group_id, access_token=self.token)
+
+        return banned_list
+
+    def isMember(self, user_id):
+        """Check is the user a member of the community
+
+        user_id - user id to whom check
+
+        """
+        is_member = self.call('groups.isMember', group_id=self.group_id, user_id=user_id, access_token=self.token)
+
+        return is_member
+
+    def removeMember(self, user_id):
+        """Remove member from community 
+
+        user_id - user id to whom check
+
+        """
+        remove_member = self.call('groups.removeUser', group_id=self.group_id, user_id=user_id, access_token=self.token)
+
+        return remove_member
+
+    def banUser(self, user_id, reason, comment, comment_visible):
+        ban_user = self.call('groups.ban', group_id=self.group_id, owner_id=user_id, reason=reason, comment=comment, comment_visible=comment_visible, access_token=self.token)
+        return ban_user
+
+    def unabanUser(self, user_id):
+        unban_user = self.call('groups.unban', group_id=self.group_id, owner_id=user_id)
 
     def isNewMessage(self, event):
         """Check message type
@@ -128,3 +178,5 @@ class VKAPI:
             return True
         else:
             return False
+
+
